<?php
/*
 * Copyright (C) 2022 Intergo Telecom Ltd <support@sms.to>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Joomla\Component\Smsto\Administrator\View\Synchronize;

\defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\GenericDataException;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Object\CMSObject;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;

/**
 * Smsto view class for the Smsto package.
 * 
 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
 *
 */
class HtmlView extends BaseHtmlView
{
	/**
	 * The Form object
	 * 
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @var  \Joomla\CMS\Form\Form
	 */
	protected $form;

	/**
	 * Is user plugin enabled?
	 * 
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @var array
	 */
	protected $user_plugin;

	/**
	 * Execute and display a template script.
	 *
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  mixed   A string if successful, otherwise an Error object.
	 */
	public function display($tpl = null)
	{
		// We don't need toolbar in the modal window.
		if ($this->getLayout() !== 'modal') {
			$this->addToolbar();
		}
		$this->form  = $this->get('Form');
		$this->user_plugin = $this->get('UserPlugin');

		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @return void
	 *
	 */
	protected function addToolbar()
	{
		$canDo = ContentHelper::getActions('com_smsto');
		$user  = Factory::getApplication()->getIdentity();

		// Get the toolbar object instance
		$toolbar = Toolbar::getInstance('toolbar');

		ToolbarHelper::title(Text::_('COM_SMSTO') . ":" . Text::_('COM_SMSTO_SYNCHRONIZE'), 'address-book');

		if ($canDo->get('core.admin') || $canDo->get('core.options')) {
			$toolbar->confirmButton('refresh')
				->text('JSUBMIT')
				->message('COM_SMSTO_SYNCHRONIZE_USERS_CONFIRM')
				->task('synchronize.syncUsers');
			$toolbar->preferences('com_smsto');
		}

		$toolbar->help(null, false, "https://intergo.atlassian.net/wiki/spaces/WOBS/pages/2208989199/Joomla%21+Bulk+SMS");
	}
}
