<?php
/*
 * Copyright (C) 2022 Intergo Telecom Ltd <support@sms.to>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Joomla\Component\Smsto\Site\Controller;

\defined('_JEXEC') or die;

use JLoader;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Response\JsonResponse;
use Joomla\Http\Http;
use Joomla\Uri\Uri;
use Smsto\Helper;

/**
 * The Smsto List Controller
 * 
 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
 *
 * @since  3.1
 */
class SmstoController extends BaseController
{
	/**
	 * Get the SMSto settings
     * 
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @return  void
	 *
	 */
	public function getParams()
	{
		$params = ComponentHelper::getParams('com_smsto');
		$params->remove('api_key');
        echo new JsonResponse($params);
        $this->app->close();
	}

	/**
	 * Call SMSto api
     * 
     * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @return  void
	 *
	 */
    public function callSmsto() {
		$params = ComponentHelper::getParams('com_smsto');
		$use_team = $params->get('use_team') ? true : false;
		$user = $this->app->getIdentity();
		$api_key = $use_team ? 'user_profile_api' : $params->get('api_key');

		$method = $this->input->getString('_method');
		$url = $this->input->getString('_url');
		$payload = $this->input->getString('payload');

		JLoader::registerNamespace('Smsto', JPATH_LIBRARIES . '/smsto');
		Helper::callSmsto($api_key, $method, $url, $payload);
		$this->app->close();
    }
}
