<?php
/*
 * Copyright (C) 2022 Intergo Telecom Ltd <support@sms.to>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Joomla\Plugin\User\Smsto\Traits;

use JLoader;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\User\User;
use Smsto\Helper;

// Protect from unauthorized access
\defined('_JEXEC') or die();

/**
 * Handle on user login
 *
 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
 */
trait UserLogin
{
	/**
	 * Method to sms notify user upon successfully login
	 * 
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @param   array  $options  Array holding options (user, responseType)
	 *
	 * @return  void
	 *
	 */
	public function onUserAfterLogin($options)
	{
		$this->loadLanguage();
		JLoader::registerNamespace('Smsto', JPATH_LIBRARIES . '/smsto');
		$this->component = Factory::getApplication()->bootComponent('com_smsto');

		if ($this->params->get('notify_admin_user_login', 1)) {
			$this->notifyAdminLogin($options['user']);
		}
	}

	/**
	 * Notify via sms administrators upon succesfully user login
	 * 
	 * @author Panayiotis Halouvas <phalouvas@kainotomo.com>
	 *
	 * @param Joomla\CMS\User\User $user
	 * @return void
	 */
	protected function notifyAdminLogin(User $user): void
	{
		$params = ComponentHelper::getParams('com_smsto');
		$api_key = $params->get('api_key');

		$phones = $this->getAdministratorsPhones();
		if (!empty($phones)) {
			$app = Factory::getApplication();
			$sitename = $app->get('sitename');
			$payload = [
				"message" => Text::sprintf('PLG_SMSTO_SEND_SMS_ADMIN_USER_LOGIN_MSG', $user->name, $user->username, $sitename),
				"to" => $phones
			];
			ob_start();
			Helper::callSmsto($api_key, 'post', "https://api.sms.to/sms/send", json_encode($payload));
			$response = json_decode(ob_get_clean(), true);
		}		
		return;
	}
}